abacusai.feature_performance_analysis — AbacusAI documentation

# abacusai.feature_performance_analysis

## Classes

`AbstractApiClass` |
`FeaturePerformanceAnalysis` | A feature performance analysis for Monitor

## Module Contents

class abacusai.feature_performance_analysis.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.feature_performance_analysis.FeaturePerformanceAnalysis(client, features=None, featureMetrics=None, metricsKeys=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A feature performance analysis for Monitor

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - features (list) – A list of the features that are being analyzed.

    - featureMetrics (list) – A list of dictionary for every feature and its metrics

    - metricsKeys (list) – A list of the keys for the metrics.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict